@@ -1,10 +1,15 @@
 use ruma_common::MilliSecondsSinceUnixEpoch;
 use ruma_events_macros::{event_enum, EventEnumFromEvent};
 use ruma_identifiers::{EventId, RoomId, RoomVersionId, UserId};
-use serde::{de, Deserialize, Serialize};
+use ruma_serde::from_raw_json_value;
+use serde::{de, Deserialize};
 use serde_json::value::RawValue as RawJsonValue;
 
-use crate::{from_raw_json_value, room::redaction::SyncRedactionEvent, Redact, UnsignedDeHelper};
+use crate::{
+    key,
+    room::{encrypted, message, redaction::SyncRoomRedactionEvent},
+    Redact, UnsignedDeHelper,
+};
 
 event_enum! {
     /// Any global account data event.
@@ -32,29 +37,14 @@ event_enum! {
         "m.call.invite",
         "m.call.hangup",
         "m.call.candidates",
-        #[cfg(feature = "unstable-pre-spec")]
-        #[cfg_attr(docsrs, doc(cfg(feature = "unstable-pre-spec")))]
         "m.key.verification.ready",
-        #[cfg(feature = "unstable-pre-spec")]
-        #[cfg_attr(docsrs, doc(cfg(feature = "unstable-pre-spec")))]
         "m.key.verification.start",
-        #[cfg(feature = "unstable-pre-spec")]
-        #[cfg_attr(docsrs, doc(cfg(feature = "unstable-pre-spec")))]
         "m.key.verification.cancel",
-        #[cfg(feature = "unstable-pre-spec")]
-        #[cfg_attr(docsrs, doc(cfg(feature = "unstable-pre-spec")))]
         "m.key.verification.accept",
-        #[cfg(feature = "unstable-pre-spec")]
-        #[cfg_attr(docsrs, doc(cfg(feature = "unstable-pre-spec")))]
         "m.key.verification.key",
-        #[cfg(feature = "unstable-pre-spec")]
-        #[cfg_attr(docsrs, doc(cfg(feature = "unstable-pre-spec")))]
         "m.key.verification.mac",
-        #[cfg(feature = "unstable-pre-spec")]
-        #[cfg_attr(docsrs, doc(cfg(feature = "unstable-pre-spec")))]
         "m.key.verification.done",
-        #[cfg(feature = "unstable-pre-spec")]
-        #[cfg_attr(docsrs, doc(cfg(feature = "unstable-pre-spec")))]
+        #[cfg(feature = "unstable-msc2677")]
         "m.reaction",
         "m.room.encrypted",
         "m.room.message",
@@ -63,7 +53,6 @@ event_enum! {
         "m.sticker",
     }
 
-
     /// Any state event.
     enum State {
         "m.policy.rule.room",
@@ -85,11 +74,7 @@ event_enum! {
         "m.room.third_party_invite",
         "m.room.tombstone",
         "m.room.topic",
-        #[cfg(feature = "unstable-pre-spec")]
-        #[cfg_attr(docsrs, doc(cfg(feature = "unstable-pre-spec")))]
         "m.space.child",
-        #[cfg(feature = "unstable-pre-spec")]
-        #[cfg_attr(docsrs, doc(cfg(feature = "unstable-pre-spec")))]
         "m.space.parent",
     }
 
@@ -100,23 +85,15 @@ event_enum! {
         "m.room_key_request",
         "m.forwarded_room_key",
         "m.key.verification.request",
-        #[cfg(feature = "unstable-pre-spec")]
-        #[cfg_attr(docsrs, doc(cfg(feature = "unstable-pre-spec")))]
         "m.key.verification.ready",
         "m.key.verification.start",
         "m.key.verification.cancel",
         "m.key.verification.accept",
         "m.key.verification.key",
         "m.key.verification.mac",
-        #[cfg(feature = "unstable-pre-spec")]
-        #[cfg_attr(docsrs, doc(cfg(feature = "unstable-pre-spec")))]
         "m.key.verification.done",
         "m.room.encrypted",
-        #[cfg(feature = "unstable-pre-spec")]
-        #[cfg_attr(docsrs, doc(cfg(feature = "unstable-pre-spec")))]
         "m.secret.request",
-        #[cfg(feature = "unstable-pre-spec")]
-        #[cfg_attr(docsrs, doc(cfg(feature = "unstable-pre-spec")))]
         "m.secret.send",
     }
 }
@@ -146,8 +123,7 @@ macro_rules! room_ev_accessor {
 
 /// Any room event.
 #[allow(clippy::large_enum_variant, clippy::exhaustive_enums)]
-#[derive(Clone, Debug, Serialize, EventEnumFromEvent)]
-#[serde(untagged)]
+#[derive(Clone, Debug, EventEnumFromEvent)]
 pub enum AnyRoomEvent {
     /// Any message event.
     Message(AnyMessageEvent),
@@ -169,15 +145,16 @@ impl AnyRoomEvent {
     room_ev_accessor!(sender: &UserId);
 }
 
-/// Any sync room event (room event without a `room_id`, as returned in `/sync` responses)
+/// Any sync room event.
+///
+/// Sync room events are room event without a `room_id`, as returned in `/sync` responses.
 #[allow(clippy::large_enum_variant, clippy::exhaustive_enums)]
-#[derive(Clone, Debug, Serialize, EventEnumFromEvent)]
-#[serde(untagged)]
+#[derive(Clone, Debug, EventEnumFromEvent)]
 pub enum AnySyncRoomEvent {
-    /// Any sync message event
+    /// Any sync message event.
     Message(AnySyncMessageEvent),
 
-    /// Any sync state event
+    /// Any sync state event.
     State(AnySyncStateEvent),
 
     /// Any sync message event that has been redacted.
@@ -193,7 +170,7 @@ impl AnySyncRoomEvent {
     room_ev_accessor!(sender: &UserId);
 
     /// Converts `self` to an `AnyRoomEvent` by adding the given a room ID.
-    pub fn into_full_event(self, room_id: RoomId) -> AnyRoomEvent {
+    pub fn into_full_event(self, room_id: Box<RoomId>) -> AnyRoomEvent {
         match self {
             Self::Message(ev) => AnyRoomEvent::Message(ev.into_full_event(room_id)),
             Self::State(ev) => AnyRoomEvent::State(ev.into_full_event(room_id)),
@@ -279,7 +256,7 @@ impl Redact for AnyRoomEvent {
     /// Redacts `self`, referencing the given event in `unsigned.redacted_because`.
     ///
     /// Does nothing for events that are already redacted.
-    fn redact(self, redaction: SyncRedactionEvent, version: &RoomVersionId) -> Self::Redacted {
+    fn redact(self, redaction: SyncRoomRedactionEvent, version: &RoomVersionId) -> Self::Redacted {
         match self {
             Self::Message(ev) => Self::Redacted::Message(ev.redact(redaction, version)),
             Self::State(ev) => Self::Redacted::State(ev.redact(redaction, version)),
@@ -315,7 +292,7 @@ impl Redact for AnySyncRoomEvent {
     /// Redacts `self`, referencing the given event in `unsigned.redacted_because`.
     ///
     /// Does nothing for events that are already redacted.
-    fn redact(self, redaction: SyncRedactionEvent, version: &RoomVersionId) -> Self::Redacted {
+    fn redact(self, redaction: SyncRoomRedactionEvent, version: &RoomVersionId) -> Self::Redacted {
         match self {
             Self::Message(ev) => Self::Redacted::Message(ev.redact(redaction, version)),
             Self::State(ev) => Self::Redacted::State(ev.redact(redaction, version)),
@@ -339,38 +316,59 @@ impl AnyMessageEventContent {
     ///
     /// This is a helper function intended for encryption. There should not be a reason to access
     /// `m.relates_to` without first destructuring an `AnyMessageEventContent` otherwise.
-    pub fn relation(&self) -> Option<crate::room::encrypted::Relation> {
-        #[cfg(feature = "unstable-pre-spec")]
+    pub fn relation(&self) -> Option<encrypted::Relation> {
         use crate::key::verification::{
-            accept::AcceptEventContent, cancel::CancelEventContent, done::DoneEventContent,
-            key::KeyEventContent, mac::MacEventContent, ready::ReadyEventContent,
-            start::StartEventContent,
+            accept::KeyVerificationAcceptEventContent, cancel::KeyVerificationCancelEventContent,
+            done::KeyVerificationDoneEventContent, key::KeyVerificationKeyEventContent,
+            mac::KeyVerificationMacEventContent, ready::KeyVerificationReadyEventContent,
+            start::KeyVerificationStartEventContent,
         };
 
         match self {
-            #[cfg(feature = "unstable-pre-spec")]
             #[rustfmt::skip]
-            AnyMessageEventContent::KeyVerificationReady(ReadyEventContent { relates_to, .. })
-            | AnyMessageEventContent::KeyVerificationStart(StartEventContent { relates_to, .. })
-            | AnyMessageEventContent::KeyVerificationCancel(CancelEventContent { relates_to, .. })
-            | AnyMessageEventContent::KeyVerificationAccept(AcceptEventContent { relates_to, .. })
-            | AnyMessageEventContent::KeyVerificationKey(KeyEventContent { relates_to, .. })
-            | AnyMessageEventContent::KeyVerificationMac(MacEventContent { relates_to, .. })
-            | AnyMessageEventContent::KeyVerificationDone(DoneEventContent { relates_to, .. }) => {
-                Some(relates_to.clone().into())
-            },
-            #[cfg(feature = "unstable-pre-spec")]
-            AnyMessageEventContent::Reaction(ev) => Some(ev.relates_to.clone().into()),
-            AnyMessageEventContent::RoomEncrypted(ev) => ev.relates_to.clone(),
-            AnyMessageEventContent::RoomMessage(ev) => ev.relates_to.clone().map(Into::into),
-            AnyMessageEventContent::CallAnswer(_)
-            | AnyMessageEventContent::CallInvite(_)
-            | AnyMessageEventContent::CallHangup(_)
-            | AnyMessageEventContent::CallCandidates(_)
-            | AnyMessageEventContent::RoomMessageFeedback(_)
-            | AnyMessageEventContent::RoomRedaction(_)
-            | AnyMessageEventContent::Sticker(_)
-            | AnyMessageEventContent::_Custom(_) => None,
+            Self::KeyVerificationReady(KeyVerificationReadyEventContent { relates_to, .. })
+            | Self::KeyVerificationStart(KeyVerificationStartEventContent { relates_to, .. })
+            | Self::KeyVerificationCancel(KeyVerificationCancelEventContent { relates_to, .. })
+            | Self::KeyVerificationAccept(KeyVerificationAcceptEventContent { relates_to, .. })
+            | Self::KeyVerificationKey(KeyVerificationKeyEventContent { relates_to, .. })
+            | Self::KeyVerificationMac(KeyVerificationMacEventContent { relates_to, .. })
+            | Self::KeyVerificationDone(KeyVerificationDoneEventContent { relates_to, .. }) => {
+                let key::verification::Relation { event_id } = relates_to;
+                Some(encrypted::Relation::Reference(encrypted::Reference {
+                    event_id: event_id.clone(),
+                }))
+            }
+            #[cfg(feature = "unstable-msc2677")]
+            Self::Reaction(ev) => {
+                use crate::reaction;
+
+                let reaction::Relation { event_id, emoji } = &ev.relates_to;
+                Some(encrypted::Relation::Annotation(encrypted::Annotation {
+                    event_id: event_id.clone(),
+                    key: emoji.clone(),
+                }))
+            }
+            Self::RoomEncrypted(ev) => ev.relates_to.clone(),
+            Self::RoomMessage(ev) => ev.relates_to.clone().map(|rel| match rel {
+                message::Relation::Reply { in_reply_to } => {
+                    encrypted::Relation::Reply { in_reply_to }
+                }
+                #[cfg(feature = "unstable-msc2676")]
+                message::Relation::Replacement(re) => {
+                    encrypted::Relation::Replacement(encrypted::Replacement {
+                        event_id: re.event_id,
+                    })
+                }
+                message::Relation::_Custom => encrypted::Relation::_Custom,
+            }),
+            Self::CallAnswer(_)
+            | Self::CallInvite(_)
+            | Self::CallHangup(_)
+            | Self::CallCandidates(_)
+            | Self::RoomMessageFeedback(_)
+            | Self::RoomRedaction(_)
+            | Self::Sticker(_)
+            | Self::_Custom { .. } => None,
         }
     }
 }
