@@ -32,7 +32,7 @@ pub struct EphemeralRoomEvent<C: EphemeralRoomEventContent> {
     pub content: C,
 
     /// The ID of the room associated with this event.
-    pub room_id: RoomId,
+    pub room_id: Box<RoomId>,
 }
 
 /// An ephemeral room event without a `room_id`.
@@ -44,25 +44,24 @@ pub struct SyncEphemeralRoomEvent<C: EphemeralRoomEventContent> {
 
 /// A message event.
 ///
-/// `MessageEvent` implements the comparison traits using only
-/// the `event_id` field, a sorted list would be sorted lexicographically based on
-/// the event's `EventId`.
+/// `MessageEvent` implements the comparison traits using only the `event_id` field, a sorted list
+/// would be sorted lexicographically based on the event's `EventId`.
 #[derive(Clone, Debug, Event)]
 pub struct MessageEvent<C: MessageEventContent> {
     /// Data specific to the event type.
     pub content: C,
 
     /// The globally unique event identifier for the user who sent the event.
-    pub event_id: EventId,
+    pub event_id: Box<EventId>,
 
     /// The fully-qualified ID of the user who sent this event.
-    pub sender: UserId,
+    pub sender: Box<UserId>,
 
     /// Timestamp in milliseconds on originating homeserver when this event was sent.
     pub origin_server_ts: MilliSecondsSinceUnixEpoch,
 
     /// The ID of the room associated with this event.
-    pub room_id: RoomId,
+    pub room_id: Box<RoomId>,
 
     /// Additional key-value pairs not signed by the homeserver.
     pub unsigned: Unsigned,
@@ -70,19 +69,18 @@ pub struct MessageEvent<C: MessageEventContent> {
 
 /// A message event without a `room_id`.
 ///
-/// `SyncMessageEvent` implements the comparison traits using only
-/// the `event_id` field, a sorted list would be sorted lexicographically based on
-/// the event's `EventId`.
+/// `SyncMessageEvent` implements the comparison traits using only the `event_id` field, a sorted
+/// list would be sorted lexicographically based on the event's `EventId`.
 #[derive(Clone, Debug, Event)]
 pub struct SyncMessageEvent<C: MessageEventContent> {
     /// Data specific to the event type.
     pub content: C,
 
     /// The globally unique event identifier for the user who sent the event.
-    pub event_id: EventId,
+    pub event_id: Box<EventId>,
 
     /// The fully-qualified ID of the user who sent this event.
-    pub sender: UserId,
+    pub sender: Box<UserId>,
 
     /// Timestamp in milliseconds on originating homeserver when this event was sent.
     pub origin_server_ts: MilliSecondsSinceUnixEpoch,
@@ -93,25 +91,24 @@ pub struct SyncMessageEvent<C: MessageEventContent> {
 
 /// A redacted message event.
 ///
-/// `RedactedMessageEvent` implements the comparison traits using only
-/// the `event_id` field, a sorted list would be sorted lexicographically based on
-/// the event's `EventId`.
+/// `RedactedMessageEvent` implements the comparison traits using only the `event_id` field, a
+/// sorted list would be sorted lexicographically based on the event's `EventId`.
 #[derive(Clone, Debug, Event)]
 pub struct RedactedMessageEvent<C: RedactedMessageEventContent> {
     /// Data specific to the event type.
     pub content: C,
 
     /// The globally unique event identifier for the user who sent the event.
-    pub event_id: EventId,
+    pub event_id: Box<EventId>,
 
     /// The fully-qualified ID of the user who sent this event.
-    pub sender: UserId,
+    pub sender: Box<UserId>,
 
     /// Timestamp in milliseconds on originating homeserver when this event was sent.
     pub origin_server_ts: MilliSecondsSinceUnixEpoch,
 
     /// The ID of the room associated with this event.
-    pub room_id: RoomId,
+    pub room_id: Box<RoomId>,
 
     /// Additional key-value pairs not signed by the homeserver.
     pub unsigned: RedactedUnsigned,
@@ -119,20 +116,18 @@ pub struct RedactedMessageEvent<C: RedactedMessageEventContent> {
 
 /// A redacted message event without a `room_id`.
 ///
-/// `RedactedSyncMessageEvent` implements the comparison traits using only
-/// the `event_id` field, a sorted list would be sorted lexicographically based on
-/// the event's `EventId`.
+/// `RedactedSyncMessageEvent` implements the comparison traits using only the `event_id` field, a
+/// sorted list would be sorted lexicographically based on the event's `EventId`.
 #[derive(Clone, Debug, Event)]
 pub struct RedactedSyncMessageEvent<C: RedactedMessageEventContent> {
     /// Data specific to the event type.
-    // #[serde(default, skip_serializing_if = "is_zst")]
     pub content: C,
 
     /// The globally unique event identifier for the user who sent the event.
-    pub event_id: EventId,
+    pub event_id: Box<EventId>,
 
     /// The fully-qualified ID of the user who sent this event.
-    pub sender: UserId,
+    pub sender: Box<UserId>,
 
     /// Timestamp in milliseconds on originating homeserver when this event was sent.
     pub origin_server_ts: MilliSecondsSinceUnixEpoch,
@@ -143,30 +138,29 @@ pub struct RedactedSyncMessageEvent<C: RedactedMessageEventContent> {
 
 /// A state event.
 ///
-/// `StateEvent` implements the comparison traits using only
-/// the `event_id` field, a sorted list would be sorted lexicographically based on
-/// the event's `EventId`.
+/// `StateEvent` implements the comparison traits using only the `event_id` field, a sorted list
+/// would be sorted lexicographically based on the event's `EventId`.
 #[derive(Clone, Debug, Event)]
 pub struct StateEvent<C: StateEventContent> {
     /// Data specific to the event type.
     pub content: C,
 
     /// The globally unique event identifier for the user who sent the event.
-    pub event_id: EventId,
+    pub event_id: Box<EventId>,
 
     /// The fully-qualified ID of the user who sent this event.
-    pub sender: UserId,
+    pub sender: Box<UserId>,
 
     /// Timestamp in milliseconds on originating homeserver when this event was sent.
     pub origin_server_ts: MilliSecondsSinceUnixEpoch,
 
     /// The ID of the room associated with this event.
-    pub room_id: RoomId,
+    pub room_id: Box<RoomId>,
 
     /// A unique key which defines the overwriting semantics for this piece of room state.
     ///
-    /// This is often an empty string, but some events send a `UserId` to show
-    /// which user the event affects.
+    /// This is often an empty string, but some events send a `UserId` to show which user the event
+    /// affects.
     pub state_key: String,
 
     /// Optional previous content for this event.
@@ -178,27 +172,26 @@ pub struct StateEvent<C: StateEventContent> {
 
 /// A state event without a `room_id`.
 ///
-/// `SyncStateEvent` implements the comparison traits using only
-/// the `event_id` field, a sorted list would be sorted lexicographically based on
-/// the event's `EventId`.
+/// `SyncStateEvent` implements the comparison traits using only the `event_id` field, a sorted list
+/// would be sorted lexicographically based on the event's `EventId`.
 #[derive(Clone, Debug, Event)]
 pub struct SyncStateEvent<C: StateEventContent> {
     /// Data specific to the event type.
     pub content: C,
 
     /// The globally unique event identifier for the user who sent the event.
-    pub event_id: EventId,
+    pub event_id: Box<EventId>,
 
     /// The fully-qualified ID of the user who sent this event.
-    pub sender: UserId,
+    pub sender: Box<UserId>,
 
     /// Timestamp in milliseconds on originating homeserver when this event was sent.
     pub origin_server_ts: MilliSecondsSinceUnixEpoch,
 
     /// A unique key which defines the overwriting semantics for this piece of room state.
     ///
-    /// This is often an empty string, but some events send a `UserId` to show
-    /// which user the event affects.
+    /// This is often an empty string, but some events send a `UserId` to show which user the event
+    /// affects.
     pub state_key: String,
 
     /// Optional previous content for this event.
@@ -208,20 +201,19 @@ pub struct SyncStateEvent<C: StateEventContent> {
     pub unsigned: Unsigned,
 }
 
-/// A stripped-down state event, used for previews of rooms the user has been
-/// invited to.
+/// A stripped-down state event, used for previews of rooms the user has been invited to.
 #[derive(Clone, Debug, Event)]
 pub struct StrippedStateEvent<C: StateEventContent> {
     /// Data specific to the event type.
     pub content: C,
 
     /// The fully-qualified ID of the user who sent this event.
-    pub sender: UserId,
+    pub sender: Box<UserId>,
 
     /// A unique key which defines the overwriting semantics for this piece of room state.
     ///
-    /// This is often an empty string, but some events send a `UserId` to show
-    /// which user the event affects.
+    /// This is often an empty string, but some events send a `UserId` to show which user the event
+    /// affects.
     pub state_key: String,
 }
 
@@ -233,8 +225,8 @@ pub struct InitialStateEvent<C: StateEventContent> {
 
     /// A unique key which defines the overwriting semantics for this piece of room state.
     ///
-    /// This is often an empty string, but some events send a `UserId` to show
-    /// which user the event affects.
+    /// This is often an empty string, but some events send a `UserId` to show which user the event
+    /// affects.
     ///
     /// Defaults to the empty string.
     #[ruma_event(default)]
@@ -243,30 +235,29 @@ pub struct InitialStateEvent<C: StateEventContent> {
 
 /// A redacted state event.
 ///
-/// `RedactedStateEvent` implements the comparison traits using only
-/// the `event_id` field, a sorted list would be sorted lexicographically based on
-/// the event's `EventId`.
+/// `RedactedStateEvent` implements the comparison traits using only the `event_id` field, a sorted
+/// list would be sorted lexicographically based on the event's `EventId`.
 #[derive(Clone, Debug, Event)]
 pub struct RedactedStateEvent<C: RedactedStateEventContent> {
     /// Data specific to the event type.
     pub content: C,
 
     /// The globally unique event identifier for the user who sent the event.
-    pub event_id: EventId,
+    pub event_id: Box<EventId>,
 
     /// The fully-qualified ID of the user who sent this event.
-    pub sender: UserId,
+    pub sender: Box<UserId>,
 
     /// Timestamp in milliseconds on originating homeserver when this event was sent.
     pub origin_server_ts: MilliSecondsSinceUnixEpoch,
 
     /// The ID of the room associated with this event.
-    pub room_id: RoomId,
+    pub room_id: Box<RoomId>,
 
     /// A unique key which defines the overwriting semantics for this piece of room state.
     ///
-    /// This is often an empty string, but some events send a `UserId` to show
-    /// which user the event affects.
+    /// This is often an empty string, but some events send a `UserId` to show which user the event
+    /// affects.
     pub state_key: String,
 
     /// Additional key-value pairs not signed by the homeserver.
@@ -275,50 +266,32 @@ pub struct RedactedStateEvent<C: RedactedStateEventContent> {
 
 /// A redacted state event without a `room_id`.
 ///
-/// `RedactedSyncStateEvent` implements the comparison traits using only
-/// the `event_id` field, a sorted list would be sorted lexicographically based on
-/// the event's `EventId`.
+/// `RedactedSyncStateEvent` implements the comparison traits using only the `event_id` field, a
+/// sorted list would be sorted lexicographically based on the event's `EventId`.
 #[derive(Clone, Debug, Event)]
 pub struct RedactedSyncStateEvent<C: RedactedStateEventContent> {
     /// Data specific to the event type.
-    // #[serde(default, skip_serializing_if = "is_zst")]
     pub content: C,
 
     /// The globally unique event identifier for the user who sent the event.
-    pub event_id: EventId,
+    pub event_id: Box<EventId>,
 
     /// The fully-qualified ID of the user who sent this event.
-    pub sender: UserId,
+    pub sender: Box<UserId>,
 
     /// Timestamp in milliseconds on originating homeserver when this event was sent.
     pub origin_server_ts: MilliSecondsSinceUnixEpoch,
 
     /// A unique key which defines the overwriting semantics for this piece of room state.
     ///
-    /// This is often an empty string, but some events send a `UserId` to show
-    /// which user the event affects.
+    /// This is often an empty string, but some events send a `UserId` to show which user the event
+    /// affects.
     pub state_key: String,
 
     /// Additional key-value pairs not signed by the homeserver.
     pub unsigned: RedactedUnsigned,
 }
 
-/// A stripped-down redacted state event.
-#[derive(Clone, Debug, Event)]
-pub struct RedactedStrippedStateEvent<C: RedactedStateEventContent> {
-    /// Data specific to the event type.
-    pub content: C,
-
-    /// The fully-qualified ID of the user who sent this event.
-    pub sender: UserId,
-
-    /// A unique key which defines the overwriting semantics for this piece of room state.
-    ///
-    /// This is often an empty string, but some events send a `UserId` to show
-    /// which user the event affects.
-    pub state_key: String,
-}
-
 /// An event sent using send-to-device messaging.
 #[derive(Clone, Debug, Event)]
 pub struct ToDeviceEvent<C: ToDeviceEventContent> {
@@ -326,7 +299,7 @@ pub struct ToDeviceEvent<C: ToDeviceEventContent> {
     pub content: C,
 
     /// The fully-qualified ID of the user who sent this event.
-    pub sender: UserId,
+    pub sender: Box<UserId>,
 }
 
 /// The decrypted payload of an `m.olm.v1.curve25519-aes-sha2` event.
@@ -336,10 +309,10 @@ pub struct DecryptedOlmV1Event<C: MessageEventContent> {
     pub content: C,
 
     /// The fully-qualified ID of the user who sent this event.
-    pub sender: UserId,
+    pub sender: Box<UserId>,
 
     /// The fully-qualified ID of the intended recipient this event.
-    pub recipient: UserId,
+    pub recipient: Box<UserId>,
 
     /// The recipient's ed25519 key.
     pub recipient_keys: OlmV1Keys,
@@ -352,7 +325,7 @@ pub struct DecryptedOlmV1Event<C: MessageEventContent> {
 #[derive(Clone, Debug, Deserialize, Serialize)]
 pub struct OlmV1Keys {
     /// An ed25519 key.
-    ed25519: String,
+    pub ed25519: String,
 }
 
 /// The decrypted payload of an `m.megolm.v1.aes-sha2` event.
@@ -362,5 +335,5 @@ pub struct DecryptedMegolmV1Event<C: MessageEventContent> {
     pub content: C,
 
     /// The ID of the room associated with the event.
-    pub room_id: RoomId,
+    pub room_id: Box<RoomId>,
 }
