@@ -1,22 +1,24 @@
-//! Types for the *m.forwarded_room_key* event.
+//! Types for the [`m.forwarded_room_key`] event.
+//!
+//! [`m.forwarded_room_key`]: https://spec.matrix.org/v1.2/client-server-api/#mforwarded_room_key
 
 use ruma_events_macros::EventContent;
 use ruma_identifiers::{EventEncryptionAlgorithm, RoomId};
 use serde::{Deserialize, Serialize};
 
-/// The payload for `ForwardedRoomKeyEvent`.
+/// The content of an `m.forwarded_room_key` event.
 ///
-/// To create an instance of this type, first create a `ForwardedRoomKeyToDeviceEventContentInit`
-/// and convert it via `ForwardedRoomKeyToDeviceEventContent::from` / `.into()`.
+/// To create an instance of this type, first create a `ToDeviceForwardedRoomKeyEventContentInit`
+/// and convert it via `ToDeviceForwardedRoomKeyEventContent::from` / `.into()`.
 #[derive(Clone, Debug, Deserialize, Serialize, EventContent)]
 #[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
 #[ruma_event(type = "m.forwarded_room_key", kind = ToDevice)]
-pub struct ForwardedRoomKeyToDeviceEventContent {
+pub struct ToDeviceForwardedRoomKeyEventContent {
     /// The encryption algorithm the key in this event is to be used with.
     pub algorithm: EventEncryptionAlgorithm,
 
     /// The room where the key is used.
-    pub room_id: RoomId,
+    pub room_id: Box<RoomId>,
 
     /// The Curve25519 key of the device which initiated the session originally.
     pub sender_key: String,
@@ -43,18 +45,18 @@ pub struct ForwardedRoomKeyToDeviceEventContent {
     pub forwarding_curve25519_key_chain: Vec<String>,
 }
 
-/// Initial set of fields of `ForwardedRoomKeyToDeviceEventContent`.
+/// Initial set of fields of `ToDeviceForwardedRoomKeyEventContent`.
 ///
 /// This struct will not be updated even if additional fields are added to `ConditionalPushRule` in
 /// a new (non-breaking) release of the Matrix specification.
 #[derive(Debug)]
 #[allow(clippy::exhaustive_structs)]
-pub struct ForwardedRoomKeyToDeviceEventContentInit {
+pub struct ToDeviceForwardedRoomKeyEventContentInit {
     /// The encryption algorithm the key in this event is to be used with.
     pub algorithm: EventEncryptionAlgorithm,
 
     /// The room where the key is used.
-    pub room_id: RoomId,
+    pub room_id: Box<RoomId>,
 
     /// The Curve25519 key of the device which initiated the session originally.
     pub sender_key: String,
@@ -81,8 +83,8 @@ pub struct ForwardedRoomKeyToDeviceEventContentInit {
     pub forwarding_curve25519_key_chain: Vec<String>,
 }
 
-impl From<ForwardedRoomKeyToDeviceEventContentInit> for ForwardedRoomKeyToDeviceEventContent {
-    fn from(init: ForwardedRoomKeyToDeviceEventContentInit) -> Self {
+impl From<ToDeviceForwardedRoomKeyEventContentInit> for ToDeviceForwardedRoomKeyEventContent {
+    fn from(init: ToDeviceForwardedRoomKeyEventContentInit) -> Self {
         Self {
             algorithm: init.algorithm,
             room_id: init.room_id,
