@@ -1,45 +1,47 @@
-//! Types for the *m.key.verification.done* event.
+//! Types for the [`m.key.verification.done`] event.
+//!
+//! [`m.key.verification.done`]: https://spec.matrix.org/v1.2/client-server-api/#mkeyverificationdone
 
 use ruma_events_macros::EventContent;
+use ruma_identifiers::TransactionId;
 use serde::{Deserialize, Serialize};
 
 use super::Relation;
-use crate::MessageEvent;
 
-/// Event signaling that the interactive key verification has successfully
-/// concluded.
-pub type DoneEvent = MessageEvent<DoneEventContent>;
-
-/// The payload for a to-device `m.key.verification.done` event.
+/// The content of a to-device `m.m.key.verification.done` event.
+///
+/// Event signaling that the interactive key verification has successfully concluded.
 #[derive(Clone, Debug, Deserialize, Serialize, EventContent)]
 #[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
 #[ruma_event(type = "m.key.verification.done", kind = ToDevice)]
-pub struct DoneToDeviceEventContent {
+pub struct ToDeviceKeyVerificationDoneEventContent {
     /// An opaque identifier for the verification process.
     ///
-    /// Must be the same as the one used for the *m.key.verification.start* message.
-    pub transaction_id: String,
+    /// Must be the same as the one used for the `m.key.verification.start` message.
+    pub transaction_id: Box<TransactionId>,
 }
 
-impl DoneToDeviceEventContent {
-    /// Creates a new `DoneToDeviceEventContent` with the given transaction ID.
-    pub fn new(transaction_id: String) -> Self {
+impl ToDeviceKeyVerificationDoneEventContent {
+    /// Creates a new `ToDeviceKeyVerificationDoneEventContent` with the given transaction ID.
+    pub fn new(transaction_id: Box<TransactionId>) -> Self {
         Self { transaction_id }
     }
 }
 
 /// The payload for a in-room `m.key.verification.done` event.
+///
+/// Event signaling that the interactive key verification has successfully concluded.
 #[derive(Clone, Debug, Deserialize, Serialize, EventContent)]
 #[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
 #[ruma_event(type = "m.key.verification.done", kind = Message)]
-pub struct DoneEventContent {
+pub struct KeyVerificationDoneEventContent {
     /// Relation signaling which verification request this event is responding to.
     #[serde(rename = "m.relates_to")]
     pub relates_to: Relation,
 }
 
-impl DoneEventContent {
-    /// Creates a new `DoneEventContent` with the given relation.
+impl KeyVerificationDoneEventContent {
+    /// Creates a new `KeyVerificationDoneEventContent` with the given relation.
     pub fn new(relates_to: Relation) -> Self {
         Self { relates_to }
     }
@@ -49,15 +51,14 @@ impl DoneEventContent {
 mod tests {
     use matches::assert_matches;
     use ruma_identifiers::event_id;
-    use ruma_serde::Raw;
     use serde_json::{from_value as from_json_value, json, to_value as to_json_value};
 
-    use super::DoneEventContent;
+    use super::KeyVerificationDoneEventContent;
     use crate::key::verification::Relation;
 
     #[test]
     fn serialization() {
-        let event_id = event_id!("$1598361704261elfgc:localhost");
+        let event_id = event_id!("$1598361704261elfgc:localhost").to_owned();
 
         let json_data = json!({
             "m.relates_to": {
@@ -66,7 +67,7 @@ mod tests {
             }
         });
 
-        let content = DoneEventContent { relates_to: Relation { event_id } };
+        let content = KeyVerificationDoneEventContent { relates_to: Relation { event_id } };
 
         assert_eq!(to_json_value(&content).unwrap(), json_data);
     }
@@ -83,15 +84,12 @@ mod tests {
         });
 
         assert_matches!(
-            from_json_value::<Raw<DoneEventContent>>(json_data)
-                .unwrap()
-                .deserialize()
-                .unwrap(),
-            DoneEventContent {
+            from_json_value::<KeyVerificationDoneEventContent>(json_data).unwrap(),
+            KeyVerificationDoneEventContent {
                 relates_to: Relation {
                     event_id
                 },
-            } if event_id == id
+            } if *event_id == *id
         );
     }
 }
