@@ -1,22 +1,22 @@
-//! Types for the *m.key.verification.ready* event.
+//! Types for the [`m.key.verification.ready`] event.
+//!
+//! [`m.key.verification.ready`]: https://spec.matrix.org/v1.2/client-server-api/#mkeyverificationready
 
 use ruma_events_macros::EventContent;
-use ruma_identifiers::DeviceIdBox;
+use ruma_identifiers::{DeviceId, TransactionId};
 use serde::{Deserialize, Serialize};
 
 use super::{Relation, VerificationMethod};
-use crate::MessageEvent;
 
-/// Response to a previously sent *m.key.verification.request* message.
-pub type ReadyEvent = MessageEvent<ReadyEventContent>;
-
-/// The payload for a to-device `m.key.verification.ready` event.
+/// The content of a to-device `m.m.key.verification.ready` event.
+///
+/// Response to a previously sent `m.key.verification.request` message.
 #[derive(Clone, Debug, Deserialize, Serialize, EventContent)]
 #[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
 #[ruma_event(type = "m.key.verification.ready", kind = ToDevice)]
-pub struct ReadyToDeviceEventContent {
+pub struct ToDeviceKeyVerificationReadyEventContent {
     /// The device ID which is initiating the request.
-    pub from_device: DeviceIdBox,
+    pub from_device: Box<DeviceId>,
 
     /// The verification methods supported by the sender.
     pub methods: Vec<VerificationMethod>,
@@ -24,30 +24,32 @@ pub struct ReadyToDeviceEventContent {
     /// An opaque identifier for the verification process.
     ///
     /// Must be unique with respect to the devices involved. Must be the same as the
-    /// `transaction_id` given in the *m.key.verification.request* from a
+    /// `transaction_id` given in the `m.key.verification.request` from a
     /// request.
-    pub transaction_id: String,
+    pub transaction_id: Box<TransactionId>,
 }
 
-impl ReadyToDeviceEventContent {
-    /// Creates a new `ReadyToDeviceEventContent` with the given device ID, verification methods and
-    /// transaction ID.
+impl ToDeviceKeyVerificationReadyEventContent {
+    /// Creates a new `ToDeviceKeyVerificationReadyEventContent` with the given device ID,
+    /// verification methods and transaction ID.
     pub fn new(
-        from_device: DeviceIdBox,
+        from_device: Box<DeviceId>,
         methods: Vec<VerificationMethod>,
-        transaction_id: String,
+        transaction_id: Box<TransactionId>,
     ) -> Self {
         Self { from_device, methods, transaction_id }
     }
 }
 
-/// The payload for an in-room `m.key.verification.ready` event.
+/// The content of an in-room `m.m.key.verification.ready` event.
+///
+/// Response to a previously sent `m.key.verification.request` message.
 #[derive(Clone, Debug, Deserialize, Serialize, EventContent)]
 #[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
 #[ruma_event(type = "m.key.verification.ready", kind = Message)]
-pub struct ReadyEventContent {
+pub struct KeyVerificationReadyEventContent {
     /// The device ID which is initiating the request.
-    pub from_device: DeviceIdBox,
+    pub from_device: Box<DeviceId>,
 
     /// The verification methods supported by the sender.
     pub methods: Vec<VerificationMethod>,
@@ -58,10 +60,11 @@ pub struct ReadyEventContent {
     pub relates_to: Relation,
 }
 
-impl ReadyEventContent {
-    /// Creates a new `ReadyEventContent` with the given device ID, methods and relation.
+impl KeyVerificationReadyEventContent {
+    /// Creates a new `KeyVerificationReadyEventContent` with the given device ID, methods and
+    /// relation.
     pub fn new(
-        from_device: DeviceIdBox,
+        from_device: Box<DeviceId>,
         methods: Vec<VerificationMethod>,
         relates_to: Relation,
     ) -> Self {
@@ -72,17 +75,16 @@ impl ReadyEventContent {
 #[cfg(test)]
 mod tests {
     use matches::assert_matches;
-    use ruma_identifiers::{event_id, DeviceIdBox};
-    use ruma_serde::Raw;
+    use ruma_identifiers::{event_id, DeviceId};
     use serde_json::{from_value as from_json_value, json, to_value as to_json_value};
 
-    use super::{ReadyEventContent, ReadyToDeviceEventContent};
+    use super::{KeyVerificationReadyEventContent, ToDeviceKeyVerificationReadyEventContent};
     use crate::key::verification::{Relation, VerificationMethod};
 
     #[test]
     fn serialization() {
-        let event_id = event_id!("$1598361704261elfgc:localhost");
-        let device: DeviceIdBox = "123".into();
+        let event_id = event_id!("$1598361704261elfgc:localhost").to_owned();
+        let device: Box<DeviceId> = "123".into();
 
         let json_data = json!({
             "from_device": device,
@@ -93,7 +95,7 @@ mod tests {
             }
         });
 
-        let content = ReadyEventContent {
+        let content = KeyVerificationReadyEventContent {
             from_device: device.clone(),
             relates_to: Relation { event_id },
             methods: vec![VerificationMethod::SasV1],
@@ -107,9 +109,9 @@ mod tests {
             "transaction_id": "456",
         });
 
-        let content = ReadyToDeviceEventContent {
+        let content = ToDeviceKeyVerificationReadyEventContent {
             from_device: device,
-            transaction_id: "456".to_owned(),
+            transaction_id: "456".into(),
             methods: vec![VerificationMethod::SasV1],
         };
 
@@ -119,7 +121,7 @@ mod tests {
     #[test]
     fn deserialization() {
         let id = event_id!("$1598361704261elfgc:localhost");
-        let device: DeviceIdBox = "123".into();
+        let device: Box<DeviceId> = "123".into();
 
         let json_data = json!({
             "from_device": device,
@@ -131,11 +133,8 @@ mod tests {
         });
 
         assert_matches!(
-            from_json_value::<Raw<ReadyEventContent>>(json_data)
-                .unwrap()
-                .deserialize()
-                .unwrap(),
-            ReadyEventContent {
+            from_json_value::<KeyVerificationReadyEventContent>(json_data).unwrap(),
+            KeyVerificationReadyEventContent {
                 from_device,
                 relates_to: Relation {
                     event_id
@@ -153,11 +152,8 @@ mod tests {
         });
 
         assert_matches!(
-            from_json_value::<Raw<ReadyToDeviceEventContent>>(json_data)
-                .unwrap()
-                .deserialize()
-                .unwrap(),
-            ReadyToDeviceEventContent {
+            from_json_value::<ToDeviceKeyVerificationReadyEventContent>(json_data).unwrap(),
+            ToDeviceKeyVerificationReadyEventContent {
                 from_device,
                 transaction_id,
                 methods,
