@@ -1,25 +1,25 @@
 //! Types for persistent data unit schemas
 //!
-//! The differences between the `RoomV1Pdu` schema and the `RoomV3Pdu` schema are
-//! that the `RoomV1Pdu` takes an `event_id` field (`RoomV3Pdu` does not), and
-//! `auth_events` and `prev_events` take `Vec<(EventId, EventHash)> rather than
-//! `Vec<EventId>` in `RoomV3Pdu`.
-//!
-//! The stubbed versions of each PDU type remove the `event_id` field (if any)
-//! and the `room_id` field for use in PDU templates.
+//! The differences between the `RoomV1Pdu` schema and the `RoomV3Pdu` schema are that the
+//! `RoomV1Pdu` takes an `event_id` field (`RoomV3Pdu` does not), and `auth_events` and
+//! `prev_events` take `Vec<(Box<EventId>, EventHash)> rather than `Vec<Box<EventId>>` in
+//! `RoomV3Pdu`.
 
 use std::collections::BTreeMap;
 
 use js_int::UInt;
 use ruma_common::MilliSecondsSinceUnixEpoch;
-use ruma_identifiers::{EventId, RoomId, ServerNameBox, ServerSigningKeyId, UserId};
-use serde::{Deserialize, Serialize};
-use serde_json::Value as JsonValue;
+use ruma_identifiers::{EventId, RoomId, ServerName, ServerSigningKeyId, UserId};
+use serde::{
+    de::{Error as _, IgnoredAny},
+    Deserialize, Deserializer, Serialize,
+};
+use serde_json::{from_str as from_json_str, value::RawValue as RawJsonValue};
 
 use crate::EventType;
 
 /// Enum for PDU schemas
-#[derive(Clone, Debug, Deserialize, Serialize)]
+#[derive(Clone, Debug, Serialize)]
 #[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
 #[serde(untagged)]
 pub enum Pdu {
@@ -35,16 +35,15 @@ pub enum Pdu {
 #[allow(clippy::exhaustive_structs)]
 pub struct RoomV1Pdu {
     /// Event ID for the PDU.
-    pub event_id: EventId,
+    pub event_id: Box<EventId>,
 
     /// The room this event belongs to.
-    pub room_id: RoomId,
+    pub room_id: Box<RoomId>,
 
     /// The user id of the user who sent this event.
-    pub sender: UserId,
+    pub sender: Box<UserId>,
 
     #[cfg(not(feature = "unstable-pre-spec"))]
-    #[cfg_attr(docsrs, doc(cfg(not(feature = "unstable-pre-spec"))))]
     /// The `server_name` of the homeserver that created this event.
     pub origin: String,
 
@@ -58,7 +57,7 @@ pub struct RoomV1Pdu {
     pub kind: EventType,
 
     /// The event's content.
-    pub content: JsonValue,
+    pub content: Box<RawJsonValue>,
 
     /// A key that determines which piece of room state the event represents.
     #[serde(skip_serializing_if = "Option::is_none")]
@@ -67,7 +66,7 @@ pub struct RoomV1Pdu {
     /// Event IDs for the most recent events in the room that the homeserver was
     /// aware of when it created this event.
     #[serde(skip_serializing_if = "Vec::is_empty")]
-    pub prev_events: Vec<(EventId, EventHash)>,
+    pub prev_events: Vec<(Box<EventId>, EventHash)>,
 
     /// The maximum depth of the `prev_events`, plus one.
     pub depth: UInt,
@@ -75,22 +74,22 @@ pub struct RoomV1Pdu {
     /// Event IDs for the authorization events that would allow this event to be
     /// in the room.
     #[serde(skip_serializing_if = "Vec::is_empty")]
-    pub auth_events: Vec<(EventId, EventHash)>,
+    pub auth_events: Vec<(Box<EventId>, EventHash)>,
 
     /// For redaction events, the ID of the event being redacted.
     #[serde(skip_serializing_if = "Option::is_none")]
-    pub redacts: Option<EventId>,
+    pub redacts: Option<Box<EventId>>,
 
     /// Additional data added by the origin server but not covered by the
     /// signatures.
     #[serde(default, skip_serializing_if = "BTreeMap::is_empty")]
-    pub unsigned: BTreeMap<String, JsonValue>,
+    pub unsigned: BTreeMap<String, Box<RawJsonValue>>,
 
     /// Content hashes of the PDU.
     pub hashes: EventHash,
 
     /// Signatures for the PDU.
-    pub signatures: BTreeMap<ServerNameBox, BTreeMap<ServerSigningKeyId, String>>,
+    pub signatures: BTreeMap<Box<ServerName>, BTreeMap<Box<ServerSigningKeyId>, String>>,
 }
 
 /// A 'persistent data unit' (event) for room versions 3 and beyond.
@@ -98,13 +97,12 @@ pub struct RoomV1Pdu {
 #[allow(clippy::exhaustive_structs)]
 pub struct RoomV3Pdu {
     /// The room this event belongs to.
-    pub room_id: RoomId,
+    pub room_id: Box<RoomId>,
 
     /// The user id of the user who sent this event.
-    pub sender: UserId,
+    pub sender: Box<UserId>,
 
     #[cfg(not(feature = "unstable-pre-spec"))]
-    #[cfg_attr(docsrs, doc(cfg(not(feature = "unstable-pre-spec"))))]
     /// The `server_name` of the homeserver that created this event.
     pub origin: String,
 
@@ -118,7 +116,7 @@ pub struct RoomV3Pdu {
     pub kind: EventType,
 
     /// The event's content.
-    pub content: JsonValue,
+    pub content: Box<RawJsonValue>,
 
     /// A key that determines which piece of room state the event represents.
     #[serde(skip_serializing_if = "Option::is_none")]
@@ -126,29 +124,29 @@ pub struct RoomV3Pdu {
 
     /// Event IDs for the most recent events in the room that the homeserver was
     /// aware of when it created this event.
-    pub prev_events: Vec<EventId>,
+    pub prev_events: Vec<Box<EventId>>,
 
     /// The maximum depth of the `prev_events`, plus one.
     pub depth: UInt,
 
     /// Event IDs for the authorization events that would allow this event to be
     /// in the room.
-    pub auth_events: Vec<EventId>,
+    pub auth_events: Vec<Box<EventId>>,
 
     /// For redaction events, the ID of the event being redacted.
     #[serde(skip_serializing_if = "Option::is_none")]
-    pub redacts: Option<EventId>,
+    pub redacts: Option<Box<EventId>>,
 
     /// Additional data added by the origin server but not covered by the
     /// signatures.
     #[serde(default, skip_serializing_if = "BTreeMap::is_empty")]
-    pub unsigned: BTreeMap<String, JsonValue>,
+    pub unsigned: BTreeMap<String, Box<RawJsonValue>>,
 
     /// Content hashes of the PDU.
     pub hashes: EventHash,
 
     /// Signatures for the PDU.
-    pub signatures: BTreeMap<ServerNameBox, BTreeMap<ServerSigningKeyId, String>>,
+    pub signatures: BTreeMap<Box<ServerName>, BTreeMap<Box<ServerSigningKeyId>, String>>,
 }
 
 /// Content hashes of a PDU.
@@ -165,3 +163,22 @@ impl EventHash {
         Self { sha256 }
     }
 }
+
+impl<'de> Deserialize<'de> for Pdu {
+    fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>
+    where
+        D: Deserializer<'de>,
+    {
+        #[derive(Deserialize)]
+        struct GetEventId {
+            event_id: Option<IgnoredAny>,
+        }
+
+        let json = Box::<RawJsonValue>::deserialize(deserializer)?;
+        if from_json_str::<GetEventId>(json.get()).map_err(D::Error::custom)?.event_id.is_some() {
+            from_json_str(json.get()).map(Self::RoomV1Pdu).map_err(D::Error::custom)
+        } else {
+            from_json_str(json.get()).map(Self::RoomV3Pdu).map_err(D::Error::custom)
+        }
+    }
+}
