@@ -1,4 +1,6 @@
-//! Types for the *m.receipt* event.
+//! Types for the [`m.receipt`] event.
+//!
+//! [`m.receipt`]: https://spec.matrix.org/v1.2/client-server-api/#mreceipt
 
 use std::{
     collections::BTreeMap,
@@ -10,22 +12,19 @@ use ruma_events_macros::EventContent;
 use ruma_identifiers::{EventId, UserId};
 use serde::{Deserialize, Serialize};
 
-use crate::EphemeralRoomEvent;
-
-/// Informs the client who has read a message specified by it's event id.
-pub type ReceiptEvent = EphemeralRoomEvent<ReceiptEventContent>;
-
-/// The payload for `ReceiptEvent`.
+/// The content of an `m.receipt` event.
 ///
 /// A mapping of event ID to a collection of receipts for this event ID. The event ID is the ID of
 /// the event being acknowledged and *not* an ID for the receipt itself.
+///
+/// Informs the client who has read a message specified by it's event id.
 #[derive(Clone, Debug, Deserialize, Serialize, EventContent)]
 #[allow(clippy::exhaustive_structs)]
 #[ruma_event(type = "m.receipt", kind = EphemeralRoom)]
-pub struct ReceiptEventContent(pub BTreeMap<EventId, Receipts>);
+pub struct ReceiptEventContent(pub BTreeMap<Box<EventId>, Receipts>);
 
 impl Deref for ReceiptEventContent {
-    type Target = BTreeMap<EventId, Receipts>;
+    type Target = BTreeMap<Box<EventId>, Receipts>;
 
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -44,7 +43,7 @@ pub type Receipts = BTreeMap<ReceiptType, UserReceipts>;
 /// A mapping of user ID to receipt.
 ///
 /// The user ID is the entity who sent this receipt.
-pub type UserReceipts = BTreeMap<UserId, Receipt>;
+pub type UserReceipts = BTreeMap<Box<UserId>, Receipt>;
 
 /// An acknowledgement of an event.
 #[derive(Clone, Debug, Default, Deserialize, Serialize)]
