@@ -1,14 +1,22 @@
-//! Types for the *m.room.member* event.
+//! Types for the [`m.room.member`] event.
+//!
+//! [`m.room.member`]: https://spec.matrix.org/v1.2/client-server-api/#mroommember
 
 use std::collections::BTreeMap;
 
 use ruma_events_macros::EventContent;
-use ruma_identifiers::{MxcUri, ServerNameBox, ServerSigningKeyId, UserId};
+use ruma_identifiers::{MxcUri, RoomVersionId, ServerName, ServerSigningKeyId, UserId};
 use ruma_serde::StringEnum;
 use serde::{Deserialize, Serialize};
+use serde_json::value::RawValue as RawJsonValue;
 
-use crate::{StateEvent, StrippedStateEvent, SyncStateEvent};
+use crate::{
+    EventContent, HasDeserializeFields, PrivOwnedStr, RedactContent, RedactedEventContent,
+    RedactedStateEventContent, StrippedStateEvent, SyncStateEvent,
+};
 
+/// The content of an `m.room.member` event.
+///
 /// The current membership state of a user in the room.
 ///
 /// Adjusts the membership state for a user in a room. It is preferable to use the membership
@@ -18,7 +26,7 @@ use crate::{StateEvent, StrippedStateEvent, SyncStateEvent};
 /// directly will fail.
 ///
 /// The `third_party_invite` property will be set if this invite is an *invite* event and is the
-/// successor of an *m.room.third_party_invite* event, and absent otherwise.
+/// successor of an `m.room.third_party_invite` event, and absent otherwise.
 ///
 /// This event may also include an `invite_room_state` key inside the event's unsigned data. If
 /// present, this contains an array of `StrippedState` events. These events provide information
@@ -34,25 +42,24 @@ use crate::{StateEvent, StrippedStateEvent, SyncStateEvent};
 /// The membership for a given user can change over time. Previous membership can be retrieved
 /// from the `prev_content` object on an event. If not present, the user's previous membership
 /// must be assumed as leave.
-pub type MemberEvent = StateEvent<MemberEventContent>;
-
-/// The payload for `MemberEvent`.
 #[derive(Clone, Debug, Deserialize, Serialize, EventContent)]
 #[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
-#[ruma_event(type = "m.room.member", kind = State)]
-pub struct MemberEventContent {
-    /// The avatar URL for this user, if any. This is added by the homeserver.
+#[ruma_event(type = "m.room.member", kind = State, custom_redacted)]
+pub struct RoomMemberEventContent {
+    /// The avatar URL for this user, if any.
     ///
-    /// If you activate the `compat` feature, this field being an empty string in JSON will give
-    /// you `None` here.
+    /// This is added by the homeserver. If you activate the `compat` feature, this field being an
+    /// empty string in JSON will result in `None` here during deserialization.
     #[serde(skip_serializing_if = "Option::is_none")]
     #[cfg_attr(
         feature = "compat",
         serde(default, deserialize_with = "ruma_serde::empty_string_as_none")
     )]
-    pub avatar_url: Option<MxcUri>,
+    pub avatar_url: Option<Box<MxcUri>>,
 
-    /// The display name for this user, if any. This is added by the homeserver.
+    /// The display name for this user, if any.
+    ///
+    /// This is added by the homeserver.
     #[serde(skip_serializing_if = "Option::is_none")]
     pub displayname: Option<String>,
 
@@ -62,7 +69,6 @@ pub struct MemberEventContent {
     pub is_direct: Option<bool>,
 
     /// The membership state of this user.
-    #[ruma_event(skip_redaction)]
     pub membership: MembershipState,
 
     /// If this member event is the successor to a third party invitation, this field will
@@ -74,21 +80,31 @@ pub struct MemberEventContent {
     ///
     /// This uses the unstable prefix in
     /// [MSC2448](https://github.com/matrix-org/matrix-doc/pull/2448).
-    #[cfg(feature = "unstable-pre-spec")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable-pre-spec")))]
-    #[serde(rename = "xyz.amorgan.blurhash")]
-    #[serde(skip_serializing_if = "Option::is_none")]
+    #[cfg(feature = "unstable-msc2448")]
+    #[serde(rename = "xyz.amorgan.blurhash", skip_serializing_if = "Option::is_none")]
     pub blurhash: Option<String>,
 
-    /// The reason for leaving a room.
-    #[cfg(feature = "unstable-pre-spec")]
-    #[cfg_attr(docsrs, doc(cfg(feature = "unstable-pre-spec")))]
+    /// User-supplied text for why their membership has changed.
+    ///
+    /// For kicks and bans, this is typically the reason for the kick or ban. For other membership
+    /// changes, this is a way for the user to communicate their intent without having to send a
+    /// message to the room, such as in a case where Bob rejects an invite from Alice about an
+    /// upcoming concert, but can't make it that day.
+    ///
+    /// Clients are not recommended to show this reason to users when receiving an invite due to
+    /// the potential for spam and abuse. Hiding the reason behind a button or other component
+    /// is recommended.
     #[serde(skip_serializing_if = "Option::is_none")]
     pub reason: Option<String>,
+
+    /// Arbitrarily chosen `UserId` (MxID) of a local user who can send an invite.
+    #[serde(rename = "join_authorised_via_users_server")]
+    #[serde(skip_serializing_if = "Option::is_none")]
+    pub join_authorized_via_users_server: Option<Box<UserId>>,
 }
 
-impl MemberEventContent {
-    /// Creates a new `MemberEventContent` with the given membership state.
+impl RoomMemberEventContent {
+    /// Creates a new `RoomMemberEventContent` with the given membership state.
     pub fn new(membership: MembershipState) -> Self {
         Self {
             membership,
@@ -96,14 +112,81 @@ impl MemberEventContent {
             displayname: None,
             is_direct: None,
             third_party_invite: None,
-            #[cfg(feature = "unstable-pre-spec")]
+            #[cfg(feature = "unstable-msc2448")]
             blurhash: None,
-            #[cfg(feature = "unstable-pre-spec")]
             reason: None,
+            join_authorized_via_users_server: None,
         }
     }
 }
 
+impl RedactContent for RoomMemberEventContent {
+    type Redacted = RedactedRoomMemberEventContent;
+
+    fn redact(self, _version: &RoomVersionId) -> RedactedRoomMemberEventContent {
+        RedactedRoomMemberEventContent {
+            membership: self.membership,
+            join_authorized_via_users_server: match _version {
+                RoomVersionId::V9 => self.join_authorized_via_users_server,
+                _ => None,
+            },
+        }
+    }
+}
+
+/// A member event that has been redacted.
+#[derive(Clone, Debug, Deserialize, Serialize)]
+#[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
+pub struct RedactedRoomMemberEventContent {
+    /// The membership state of this user.
+    pub membership: MembershipState,
+
+    /// An arbitrary user who has the power to issue invites.
+    ///
+    /// This is redacted in room versions 8 and below. It is used for validating
+    /// joins when the join rule is restricted.
+    #[serde(rename = "join_authorised_via_users_server")]
+    pub join_authorized_via_users_server: Option<Box<UserId>>,
+}
+
+impl RedactedRoomMemberEventContent {
+    /// Create a `RedactedRoomMemberEventContent` with the given membership.
+    pub fn new(membership: MembershipState) -> Self {
+        Self { membership, join_authorized_via_users_server: None }
+    }
+}
+
+impl EventContent for RedactedRoomMemberEventContent {
+    fn event_type(&self) -> &str {
+        "m.room.member"
+    }
+
+    fn from_parts(event_type: &str, content: &RawJsonValue) -> serde_json::Result<Self> {
+        if event_type != "m.room.member" {
+            return Err(::serde::de::Error::custom(format!(
+                "expected event type `m.room.member`, found `{}`",
+                event_type
+            )));
+        }
+
+        serde_json::from_str(content.get())
+    }
+}
+
+// Since this redacted event has fields we leave the default `empty` method
+// that will error if called.
+impl RedactedEventContent for RedactedRoomMemberEventContent {
+    fn has_serialize_fields(&self) -> bool {
+        true
+    }
+
+    fn has_deserialize_fields() -> HasDeserializeFields {
+        HasDeserializeFields::Optional
+    }
+}
+
+impl RedactedStateEventContent for RedactedRoomMemberEventContent {}
+
 /// The membership state of a user.
 ///
 /// This type can hold an arbitrary string. To check for formats that are not available as a
@@ -128,7 +211,7 @@ pub enum MembershipState {
     Leave,
 
     #[doc(hidden)]
-    _Custom(String),
+    _Custom(PrivOwnedStr),
 }
 
 impl MembershipState {
@@ -167,11 +250,11 @@ pub struct SignedContent {
     /// The invited Matrix user ID.
     ///
     /// Must be equal to the user_id property of the event.
-    pub mxid: UserId,
+    pub mxid: Box<UserId>,
 
     /// A single signature from the verifying server, in the format specified by the Signing Events
     /// section of the server-server API.
-    pub signatures: BTreeMap<ServerNameBox, BTreeMap<ServerSigningKeyId, String>>,
+    pub signatures: BTreeMap<Box<ServerName>, BTreeMap<Box<ServerSigningKeyId>, String>>,
 
     /// The token property of the containing `third_party_invite` object.
     pub token: String,
@@ -180,8 +263,8 @@ pub struct SignedContent {
 impl SignedContent {
     /// Creates a new `SignedContent` with the given mxid, signature and token.
     pub fn new(
-        mxid: UserId,
-        signatures: BTreeMap<ServerNameBox, BTreeMap<ServerSigningKeyId, String>>,
+        mxid: Box<UserId>,
+        signatures: BTreeMap<Box<ServerName>, BTreeMap<Box<ServerSigningKeyId>, String>>,
         token: String,
     ) -> Self {
         Self { mxid, signatures, token }
@@ -238,11 +321,11 @@ pub enum MembershipChange {
     NotImplemented,
 }
 
-/// Internal function so all `MemberEventContent` state event kinds can share the same
+/// Internal function so all `RoomMemberEventContent` state event kinds can share the same
 /// implementation.
 fn membership_change(
-    content: &MemberEventContent,
-    prev_content: Option<&MemberEventContent>,
+    content: &RoomMemberEventContent,
+    prev_content: Option<&RoomMemberEventContent>,
     sender: &UserId,
     state_key: &str,
 ) -> MembershipChange {
@@ -252,16 +335,16 @@ fn membership_change(
     let prev_content = if let Some(prev_content) = &prev_content {
         prev_content
     } else {
-        &MemberEventContent {
+        &RoomMemberEventContent {
             avatar_url: None,
             displayname: None,
             is_direct: None,
             membership: St::Leave,
             third_party_invite: None,
-            #[cfg(feature = "unstable-pre-spec")]
+            #[cfg(feature = "unstable-msc2448")]
             blurhash: None,
-            #[cfg(feature = "unstable-pre-spec")]
             reason: None,
+            join_authorized_via_users_server: None,
         }
     };
 
@@ -295,28 +378,34 @@ fn membership_change(
     }
 }
 
-impl MemberEvent {
-    /// Helper function for membership change. Check [the specification][spec] for details.
+impl RoomMemberEvent {
+    /// Helper function for membership change.
     ///
-    /// [spec]: https://matrix.org/docs/spec/client_server/r0.6.1#m-room-member
+    /// Check [the specification][spec] for details.
+    ///
+    /// [spec]: https://spec.matrix.org/v1.2/client-server-api/#mroommember
     pub fn membership_change(&self) -> MembershipChange {
         membership_change(&self.content, self.prev_content.as_ref(), &self.sender, &self.state_key)
     }
 }
 
-impl SyncStateEvent<MemberEventContent> {
-    /// Helper function for membership change. Check [the specification][spec] for details.
+impl SyncStateEvent<RoomMemberEventContent> {
+    /// Helper function for membership change.
     ///
-    /// [spec]: https://matrix.org/docs/spec/client_server/r0.6.1#m-room-member
+    /// Check [the specification][spec] for details.
+    ///
+    /// [spec]: https://spec.matrix.org/v1.2/client-server-api/#mroommember
     pub fn membership_change(&self) -> MembershipChange {
         membership_change(&self.content, self.prev_content.as_ref(), &self.sender, &self.state_key)
     }
 }
 
-impl StrippedStateEvent<MemberEventContent> {
-    /// Helper function for membership change. Check [the specification][spec] for details.
+impl StrippedStateEvent<RoomMemberEventContent> {
+    /// Helper function for membership change.
     ///
-    /// [spec]: https://matrix.org/docs/spec/client_server/r0.6.1#m-room-member
+    /// Check [the specification][spec] for details.
+    ///
+    /// [spec]: https://spec.matrix.org/v1.2/client-server-api/#mroommember
     pub fn membership_change(&self) -> MembershipChange {
         membership_change(&self.content, None, &self.sender, &self.state_key)
     }
@@ -329,10 +418,9 @@ mod tests {
     use matches::assert_matches;
     use ruma_common::MilliSecondsSinceUnixEpoch;
     use ruma_identifiers::{server_name, server_signing_key_id};
-    use ruma_serde::Raw;
     use serde_json::{from_value as from_json_value, json};
 
-    use super::{MemberEventContent, MembershipState, SignedContent, ThirdPartyInvite};
+    use super::{MembershipState, RoomMemberEventContent, SignedContent, ThirdPartyInvite};
     use crate::StateEvent;
 
     #[test]
@@ -350,12 +438,9 @@ mod tests {
         });
 
         assert_matches!(
-            from_json_value::<Raw<StateEvent<MemberEventContent>>>(json)
-                .unwrap()
-                .deserialize()
-                .unwrap(),
-            StateEvent::<MemberEventContent> {
-                content: MemberEventContent {
+            from_json_value::<StateEvent<RoomMemberEventContent>>(json).unwrap(),
+            StateEvent {
+                content: RoomMemberEventContent {
                     avatar_url: None,
                     displayname: None,
                     is_direct: None,
@@ -397,12 +482,9 @@ mod tests {
         });
 
         assert_matches!(
-            from_json_value::<Raw<StateEvent<MemberEventContent>>>(json)
-                .unwrap()
-                .deserialize()
-                .unwrap(),
-            StateEvent::<MemberEventContent> {
-                content: MemberEventContent {
+            from_json_value::<StateEvent<RoomMemberEventContent>>(json).unwrap(),
+            StateEvent {
+                content: RoomMemberEventContent {
                     avatar_url: None,
                     displayname: None,
                     is_direct: None,
@@ -416,7 +498,7 @@ mod tests {
                 sender,
                 state_key,
                 unsigned,
-                prev_content: Some(MemberEventContent {
+                prev_content: Some(RoomMemberEventContent {
                     avatar_url: None,
                     displayname: None,
                     is_direct: None,
@@ -463,12 +545,9 @@ mod tests {
         });
 
         assert_matches!(
-            from_json_value::<Raw<StateEvent<MemberEventContent>>>(json)
-                .unwrap()
-                .deserialize()
-                .unwrap(),
-            StateEvent::<MemberEventContent> {
-                content: MemberEventContent {
+            from_json_value::<StateEvent<RoomMemberEventContent>>(json).unwrap(),
+            StateEvent {
+                content: RoomMemberEventContent {
                     avatar_url: Some(avatar_url),
                     displayname: Some(displayname),
                     is_direct: Some(true),
@@ -486,13 +565,13 @@ mod tests {
                 state_key,
                 unsigned,
                 prev_content: None,
-            } if avatar_url.to_string() == "mxc://example.org/SEsfnsuifSDFSSEF"
+            } if avatar_url == "mxc://example.org/SEsfnsuifSDFSSEF"
                 && displayname == "Alice Margatroid"
                 && third_party_displayname == "alice"
                 && mxid == "@alice:example.org"
                 && signatures == btreemap! {
-                    server_name!("magic.forest") => btreemap! {
-                        server_signing_key_id!("ed25519:3") => "foobar".to_owned()
+                    server_name!("magic.forest").to_owned() => btreemap! {
+                        server_signing_key_id!("ed25519:3").to_owned() => "foobar".to_owned()
                     }
                 }
                 && token == "abc123"
@@ -538,12 +617,9 @@ mod tests {
         });
 
         assert_matches!(
-            from_json_value::<Raw<StateEvent<MemberEventContent>>>(json)
-                .unwrap()
-                .deserialize()
-                .unwrap(),
-            StateEvent::<MemberEventContent> {
-                content: MemberEventContent {
+            from_json_value::<StateEvent<RoomMemberEventContent>>(json).unwrap(),
+            StateEvent {
+                content: RoomMemberEventContent {
                     avatar_url: None,
                     displayname: None,
                     is_direct: None,
@@ -557,7 +633,7 @@ mod tests {
                 sender,
                 state_key,
                 unsigned,
-                prev_content: Some(MemberEventContent {
+                prev_content: Some(RoomMemberEventContent {
                     avatar_url: Some(avatar_url),
                     displayname: Some(displayname),
                     is_direct: Some(true),
@@ -574,13 +650,13 @@ mod tests {
                 && sender == "@alice:example.org"
                 && state_key == "@alice:example.org"
                 && unsigned.is_empty()
-                && avatar_url.to_string() == "mxc://example.org/SEsfnsuifSDFSSEF"
+                && avatar_url == "mxc://example.org/SEsfnsuifSDFSSEF"
                 && displayname == "Alice Margatroid"
                 && third_party_displayname == "alice"
                 && mxid == "@alice:example.org"
                 && signatures == btreemap! {
-                    server_name!("magic.forest") => btreemap! {
-                        server_signing_key_id!("ed25519:3") => "foobar".to_owned()
+                    server_name!("magic.forest").to_owned() => btreemap! {
+                        server_signing_key_id!("ed25519:3").to_owned() => "foobar".to_owned()
                     }
                 }
                 && token == "abc123"
@@ -588,7 +664,7 @@ mod tests {
 
         #[cfg(feature = "compat")]
         assert_matches!(
-            from_json_value::<Raw<StateEvent<MemberEventContent>>>(json!({
+            from_json_value::<StateEvent<RoomMemberEventContent>>(json!({
                 "type": "m.room.member",
                 "content": {
                     "membership": "join"
@@ -616,12 +692,9 @@ mod tests {
                 "room_id": "!jEsUZKDJdhlrceRyVU:example.org",
                 "sender": "@alice:example.org",
                 "state_key": "@alice:example.org"
-            }))
-                .unwrap()
-                .deserialize()
-                .unwrap(),
-            StateEvent::<MemberEventContent> {
-                content: MemberEventContent {
+            })).unwrap(),
+            StateEvent {
+                content: RoomMemberEventContent {
                     avatar_url: None,
                     displayname: None,
                     is_direct: None,
@@ -635,7 +708,7 @@ mod tests {
                 sender,
                 state_key,
                 unsigned,
-                prev_content: Some(MemberEventContent {
+                prev_content: Some(RoomMemberEventContent {
                     avatar_url: None,
                     displayname: Some(displayname),
                     is_direct: Some(true),
@@ -656,11 +729,55 @@ mod tests {
                 && third_party_displayname == "alice"
                 && mxid == "@alice:example.org"
                 && signatures == btreemap! {
-                    server_name!("magic.forest") => btreemap! {
-                        server_signing_key_id!("ed25519:3") => "foobar".to_owned()
+                    server_name!("magic.forest").to_owned() => btreemap! {
+                        server_signing_key_id!("ed25519:3").to_owned() => "foobar".to_owned()
                     }
                 }
                 && token == "abc123"
         );
     }
+
+    #[test]
+    fn serde_with_join_authorized() {
+        let json = json!({
+            "type": "m.room.member",
+            "content": {
+                "membership": "join",
+                "join_authorised_via_users_server": "@notcarl:example.com"
+            },
+            "event_id": "$h29iv0s8:example.com",
+            "origin_server_ts": 1,
+            "room_id": "!n8f893n9:example.com",
+            "sender": "@carl:example.com",
+            "state_key": "example.com"
+        });
+
+        assert_matches!(
+            from_json_value::<StateEvent<RoomMemberEventContent>>(json).unwrap(),
+            StateEvent {
+                content: RoomMemberEventContent {
+                    avatar_url: None,
+                    displayname: None,
+                    is_direct: None,
+                    membership: MembershipState::Join,
+                    third_party_invite: None,
+                    join_authorized_via_users_server: Some(authed),
+                    ..
+                },
+                event_id,
+                origin_server_ts,
+                room_id,
+                sender,
+                state_key,
+                unsigned,
+                prev_content: None,
+            } if event_id == "$h29iv0s8:example.com"
+                && origin_server_ts == MilliSecondsSinceUnixEpoch(uint!(1))
+                && room_id == "!n8f893n9:example.com"
+                && sender == "@carl:example.com"
+                && authed == "@notcarl:example.com"
+                && state_key == "example.com"
+                && unsigned.is_empty()
+        );
+    }
 }
