@@ -1,30 +1,32 @@
-//! Types for the *m.room.power_levels* event.
+//! Types for the [`m.room.power_levels`] event.
+//!
+//! [`m.room.power_levels`]: https://spec.matrix.org/v1.2/client-server-api/#mroompower_levels
 
 use std::collections::BTreeMap;
 
 use js_int::{int, Int};
-use ruma_common::power_levels::default_power_level;
+use ruma_common::power_levels::{default_power_level, NotificationPowerLevels};
 use ruma_events_macros::EventContent;
 use ruma_identifiers::UserId;
 use serde::{Deserialize, Serialize};
 
-use crate::{EventType, StateEvent};
-
-use ruma_common::power_levels::NotificationPowerLevels;
+use crate::EventType;
 
+/// The content of an `m.room.power_levels` event.
+///
 /// Defines the power levels (privileges) of users in the room.
-pub type PowerLevelsEvent = StateEvent<PowerLevelsEventContent>;
-
-/// The payload for `PowerLevelsEvent`.
 #[derive(Clone, Debug, Deserialize, Serialize, EventContent)]
 #[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
 #[ruma_event(type = "m.room.power_levels", kind = State)]
-pub struct PowerLevelsEventContent {
+pub struct RoomPowerLevelsEventContent {
     /// The level required to ban a user.
     ///
     /// If you activate the `compat` feature, deserialization will work for stringified
     /// integers too.
-    #[cfg_attr(feature = "compat", serde(deserialize_with = "ruma_serde::int_or_string_to_int"))]
+    #[cfg_attr(
+        feature = "compat",
+        serde(deserialize_with = "ruma_serde::deserialize_v1_powerlevel")
+    )]
     #[serde(default = "default_power_level", skip_serializing_if = "is_default_power_level")]
     #[ruma_event(skip_redaction)]
     pub ban: Int,
@@ -37,7 +39,7 @@ pub struct PowerLevelsEventContent {
     /// integers too.
     #[cfg_attr(
         feature = "compat",
-        serde(deserialize_with = "ruma_serde::btreemap_int_or_string_to_int_values")
+        serde(deserialize_with = "ruma_serde::btreemap_deserialize_v1_powerlevel_values")
     )]
     #[serde(default, skip_serializing_if = "BTreeMap::is_empty")]
     #[ruma_event(skip_redaction)]
@@ -47,7 +49,10 @@ pub struct PowerLevelsEventContent {
     ///
     /// If you activate the `compat` feature, deserialization will work for stringified
     /// integers too.
-    #[cfg_attr(feature = "compat", serde(deserialize_with = "ruma_serde::int_or_string_to_int"))]
+    #[cfg_attr(
+        feature = "compat",
+        serde(deserialize_with = "ruma_serde::deserialize_v1_powerlevel")
+    )]
     #[serde(default, skip_serializing_if = "ruma_serde::is_default")]
     #[ruma_event(skip_redaction)]
     pub events_default: Int,
@@ -56,7 +61,10 @@ pub struct PowerLevelsEventContent {
     ///
     /// If you activate the `compat` feature, deserialization will work for stringified
     /// integers too.
-    #[cfg_attr(feature = "compat", serde(deserialize_with = "ruma_serde::int_or_string_to_int"))]
+    #[cfg_attr(
+        feature = "compat",
+        serde(deserialize_with = "ruma_serde::deserialize_v1_powerlevel")
+    )]
     #[serde(default = "default_power_level", skip_serializing_if = "is_default_power_level")]
     pub invite: Int,
 
@@ -64,7 +72,10 @@ pub struct PowerLevelsEventContent {
     ///
     /// If you activate the `compat` feature, deserialization will work for stringified
     /// integers too.
-    #[cfg_attr(feature = "compat", serde(deserialize_with = "ruma_serde::int_or_string_to_int"))]
+    #[cfg_attr(
+        feature = "compat",
+        serde(deserialize_with = "ruma_serde::deserialize_v1_powerlevel")
+    )]
     #[serde(default = "default_power_level", skip_serializing_if = "is_default_power_level")]
     #[ruma_event(skip_redaction)]
     pub kick: Int,
@@ -73,7 +84,10 @@ pub struct PowerLevelsEventContent {
     ///
     /// If you activate the `compat` feature, deserialization will work for stringified
     /// integers too.
-    #[cfg_attr(feature = "compat", serde(deserialize_with = "ruma_serde::int_or_string_to_int"))]
+    #[cfg_attr(
+        feature = "compat",
+        serde(deserialize_with = "ruma_serde::deserialize_v1_powerlevel")
+    )]
     #[serde(default = "default_power_level", skip_serializing_if = "is_default_power_level")]
     #[ruma_event(skip_redaction)]
     pub redact: Int,
@@ -82,7 +96,10 @@ pub struct PowerLevelsEventContent {
     ///
     /// If you activate the `compat` feature, deserialization will work for stringified
     /// integers too.
-    #[cfg_attr(feature = "compat", serde(deserialize_with = "ruma_serde::int_or_string_to_int"))]
+    #[cfg_attr(
+        feature = "compat",
+        serde(deserialize_with = "ruma_serde::deserialize_v1_powerlevel")
+    )]
     #[serde(default = "default_power_level", skip_serializing_if = "is_default_power_level")]
     #[ruma_event(skip_redaction)]
     pub state_default: Int,
@@ -95,17 +112,20 @@ pub struct PowerLevelsEventContent {
     /// integers too.
     #[cfg_attr(
         feature = "compat",
-        serde(deserialize_with = "ruma_serde::btreemap_int_or_string_to_int_values")
+        serde(deserialize_with = "ruma_serde::btreemap_deserialize_v1_powerlevel_values")
     )]
     #[serde(default, skip_serializing_if = "BTreeMap::is_empty")]
     #[ruma_event(skip_redaction)]
-    pub users: BTreeMap<UserId, Int>,
+    pub users: BTreeMap<Box<UserId>, Int>,
 
     /// The default power level for every user in the room.
     ///
     /// If you activate the `compat` feature, deserialization will work for stringified
     /// integers too.
-    #[cfg_attr(feature = "compat", serde(deserialize_with = "ruma_serde::int_or_string_to_int"))]
+    #[cfg_attr(
+        feature = "compat",
+        serde(deserialize_with = "ruma_serde::deserialize_v1_powerlevel")
+    )]
     #[serde(default, skip_serializing_if = "ruma_serde::is_default")]
     #[ruma_event(skip_redaction)]
     pub users_default: Int,
@@ -117,8 +137,8 @@ pub struct PowerLevelsEventContent {
     pub notifications: NotificationPowerLevels,
 }
 
-impl PowerLevelsEventContent {
-    /// Creates a new `PowerLevelsEventContent` with all-default values.
+impl RoomPowerLevelsEventContent {
+    /// Creates a new `RoomPowerLevelsEventContent` with all-default values.
     pub fn new() -> Self {
         // events_default and users_default having a default of 0 while the others have a default
         // of 50 is not an oversight, these defaults are from the Matrix specification.
@@ -137,7 +157,7 @@ impl PowerLevelsEventContent {
     }
 }
 
-impl Default for PowerLevelsEventContent {
+impl Default for RoomPowerLevelsEventContent {
     fn default() -> Self {
         Self::new()
     }
@@ -160,7 +180,7 @@ mod tests {
     use ruma_identifiers::{event_id, room_id, user_id};
     use serde_json::{json, to_value as to_json_value};
 
-    use super::{default_power_level, NotificationPowerLevels, PowerLevelsEventContent};
+    use super::{default_power_level, NotificationPowerLevels, RoomPowerLevelsEventContent};
     use crate::{EventType, StateEvent, Unsigned};
 
     #[test]
@@ -168,7 +188,7 @@ mod tests {
         let default = default_power_level();
 
         let power_levels_event = StateEvent {
-            content: PowerLevelsEventContent {
+            content: RoomPowerLevelsEventContent {
                 ban: default,
                 events: BTreeMap::new(),
                 events_default: int!(0),
@@ -180,12 +200,12 @@ mod tests {
                 users_default: int!(0),
                 notifications: NotificationPowerLevels::default(),
             },
-            event_id: event_id!("$h29iv0s8:example.com"),
+            event_id: event_id!("$h29iv0s8:example.com").to_owned(),
             origin_server_ts: MilliSecondsSinceUnixEpoch(uint!(1)),
             prev_content: None,
-            room_id: room_id!("!n8f893n9:example.com"),
+            room_id: room_id!("!n8f893n9:example.com").to_owned(),
             unsigned: Unsigned::default(),
-            sender: user_id!("@carl:example.com"),
+            sender: user_id!("@carl:example.com").to_owned(),
             state_key: "".into(),
         };
 
@@ -207,7 +227,7 @@ mod tests {
     fn serialization_with_all_fields() {
         let user = user_id!("@carl:example.com");
         let power_levels_event = StateEvent {
-            content: PowerLevelsEventContent {
+            content: RoomPowerLevelsEventContent {
                 ban: int!(23),
                 events: btreemap! {
                     EventType::Dummy => int!(23)
@@ -218,14 +238,14 @@ mod tests {
                 redact: int!(23),
                 state_default: int!(23),
                 users: btreemap! {
-                    user.clone() => int!(23)
+                    user.to_owned() => int!(23)
                 },
                 users_default: int!(23),
                 notifications: assign!(NotificationPowerLevels::new(), { room: int!(23) }),
             },
-            event_id: event_id!("$h29iv0s8:example.com"),
+            event_id: event_id!("$h29iv0s8:example.com").to_owned(),
             origin_server_ts: MilliSecondsSinceUnixEpoch(uint!(1)),
-            prev_content: Some(PowerLevelsEventContent {
+            prev_content: Some(RoomPowerLevelsEventContent {
                 // Make just one field different so we at least know they're two different objects.
                 ban: int!(42),
                 events: btreemap! {
@@ -237,14 +257,14 @@ mod tests {
                 redact: int!(42),
                 state_default: int!(42),
                 users: btreemap! {
-                    user.clone() => int!(42)
+                    user.to_owned() => int!(42)
                 },
                 users_default: int!(42),
                 notifications: assign!(NotificationPowerLevels::new(), { room: int!(42) }),
             }),
-            room_id: room_id!("!n8f893n9:example.com"),
+            room_id: room_id!("!n8f893n9:example.com").to_owned(),
             unsigned: Unsigned { age: Some(int!(100)), ..Unsigned::default() },
-            sender: user,
+            sender: user.to_owned(),
             state_key: "".into(),
         };
 
