@@ -1,24 +1,23 @@
-//! Types for the *m.room.topic* event.
+//! Types for the [`m.room.topic`] event.
+//!
+//! [`m.room.topic`]: https://spec.matrix.org/v1.2/client-server-api/#mroomtopic
 
 use ruma_events_macros::EventContent;
 use serde::{Deserialize, Serialize};
 
-use crate::StateEvent;
-
+/// The content of an `m.room.topic` event.
+///
 /// A topic is a short message detailing what is currently being discussed in the room.
-pub type TopicEvent = StateEvent<TopicEventContent>;
-
-/// The payload for `TopicEvent`.
 #[derive(Clone, Debug, Deserialize, Serialize, EventContent)]
 #[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
 #[ruma_event(type = "m.room.topic", kind = State)]
-pub struct TopicEventContent {
+pub struct RoomTopicEventContent {
     /// The topic text.
     pub topic: String,
 }
 
-impl TopicEventContent {
-    /// Creates a new `TopicEventContent` with the given topic.
+impl RoomTopicEventContent {
+    /// Creates a new `RoomTopicEventContent` with the given topic.
     pub fn new(topic: String) -> Self {
         Self { topic }
     }
