@@ -1,26 +1,25 @@
-//! Types for the *m.space.child* event.
+//! Types for the [`m.space.child`] event.
+//!
+//! [`m.space.child`]: https://spec.matrix.org/v1.2/client-server-api/#mspacechild
 
 use ruma_events_macros::EventContent;
-use ruma_identifiers::ServerNameBox;
+use ruma_identifiers::ServerName;
 use serde::{Deserialize, Serialize};
 
-use crate::StateEvent;
-
+/// The content of an `m.space.child` event.
+///
 /// The admins of a space can advertise rooms and subspaces for their space by setting
 /// `m.space.child` state events.
 ///
 /// The `state_key` is the ID of a child room or space, and the content must contain a `via` key
 /// which gives a list of candidate servers that can be used to join the room.
-pub type ChildEvent = StateEvent<ChildEventContent>;
-
-/// The payload for `ChildEvent`.
 #[derive(Clone, Debug, Default, Deserialize, Serialize, EventContent)]
 #[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
 #[ruma_event(type = "m.space.child", kind = State)]
-pub struct ChildEventContent {
+pub struct SpaceChildEventContent {
     /// List of candidate servers that can be used to join the room.
     #[serde(skip_serializing_if = "Option::is_none")]
-    pub via: Option<Vec<ServerNameBox>>,
+    pub via: Option<Vec<Box<ServerName>>>,
 
     /// Provide a default ordering of siblings in the room list.
     ///
@@ -44,7 +43,7 @@ pub struct ChildEventContent {
     pub suggested: Option<bool>,
 }
 
-impl ChildEventContent {
+impl SpaceChildEventContent {
     /// Creates a new `ChildEventContent`.
     pub fn new() -> Self {
         Self::default()
@@ -53,14 +52,15 @@ impl ChildEventContent {
 
 #[cfg(test)]
 mod tests {
-    use super::ChildEventContent;
     use ruma_identifiers::server_name;
     use serde_json::{json, to_value as to_json_value};
 
+    use super::SpaceChildEventContent;
+
     #[test]
     fn space_child_serialization() {
-        let content = ChildEventContent {
-            via: Some(vec![server_name!("example.com")]),
+        let content = SpaceChildEventContent {
+            via: Some(vec![server_name!("example.com").to_owned()]),
             order: Some("uwu".to_owned()),
             suggested: Some(false),
         };
@@ -76,7 +76,7 @@ mod tests {
 
     #[test]
     fn space_child_empty_serialization() {
-        let content = ChildEventContent { via: None, order: None, suggested: None };
+        let content = SpaceChildEventContent { via: None, order: None, suggested: None };
 
         let json = json!({});
 
