@@ -1,26 +1,25 @@
-//! Types for the *m.space.child* event.
+//! Types for the [`m.space.parent`] event.
+//!
+//! [`m.space.parent`]: https://spec.matrix.org/v1.2/client-server-api/#mspaceparent
 
 use ruma_events_macros::EventContent;
-use ruma_identifiers::ServerNameBox;
+use ruma_identifiers::ServerName;
 use serde::{Deserialize, Serialize};
 
-use crate::StateEvent;
-
+/// The content of an `m.space.parent` event.
+///
 /// Rooms can claim parents via the `m.space.parent` state event.
 ///
 /// Similar to `m.space.child`, the `state_key` is the ID of the parent space, and the content must
 /// contain a `via` key which gives a list of candidate servers that can be used to join the
 /// parent.
-pub type ParentEvent = StateEvent<ParentEventContent>;
-
-/// The payload for `ParentEvent`.
 #[derive(Clone, Debug, Deserialize, Serialize, EventContent)]
 #[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
 #[ruma_event(type = "m.space.parent", kind = State)]
-pub struct ParentEventContent {
+pub struct SpaceParentEventContent {
     /// List of candidate servers that can be used to join the room.
     #[serde(skip_serializing_if = "Option::is_none")]
-    pub via: Option<Vec<ServerNameBox>>,
+    pub via: Option<Vec<Box<ServerName>>>,
 
     /// Determines whether this is the main parent for the space.
     ///
@@ -32,7 +31,7 @@ pub struct ParentEventContent {
     pub canonical: bool,
 }
 
-impl ParentEventContent {
+impl SpaceParentEventContent {
     /// Creates a new `ParentEventContent` with the given canonical flag.
     pub fn new(canonical: bool) -> Self {
         Self { via: None, canonical }
@@ -41,14 +40,17 @@ impl ParentEventContent {
 
 #[cfg(test)]
 mod tests {
-    use super::ParentEventContent;
     use ruma_identifiers::server_name;
     use serde_json::{json, to_value as to_json_value};
 
+    use super::SpaceParentEventContent;
+
     #[test]
     fn space_parent_serialization() {
-        let content =
-            ParentEventContent { via: Some(vec![server_name!("example.com")]), canonical: true };
+        let content = SpaceParentEventContent {
+            via: Some(vec![server_name!("example.com").to_owned()]),
+            canonical: true,
+        };
 
         let json = json!({
             "via": ["example.com"],
@@ -60,7 +62,7 @@ mod tests {
 
     #[test]
     fn space_parent_empty_serialization() {
-        let content = ParentEventContent { via: None, canonical: true };
+        let content = SpaceParentEventContent { via: None, canonical: true };
 
         let json = json!({
             "canonical": true,
