@@ -1,4 +1,6 @@
-//! Types for the *m.tag* event.
+//! Types for the [`m.tag`] event.
+//!
+//! [`m.tag`]: https://spec.matrix.org/v1.2/client-server-api/#mtag
 
 use std::{collections::BTreeMap, error::Error, fmt, str::FromStr};
 
@@ -6,15 +8,14 @@ use ruma_events_macros::EventContent;
 use ruma_serde::deserialize_cow_str;
 use serde::{Deserialize, Serialize};
 
-use crate::RoomAccountDataEvent;
-
-/// Informs the client of tags on a room.
-pub type TagEvent = RoomAccountDataEvent<TagEventContent>;
+use crate::PrivOwnedStr;
 
 /// Map of tag names to tag info.
 pub type Tags = BTreeMap<TagName, TagInfo>;
 
-/// The payload for `TagEvent`.
+/// The content of an `m.tag` event.
+///
+/// Informs the client of tags on a room.
 #[derive(Clone, Debug, Deserialize, Serialize, EventContent)]
 #[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
 #[ruma_event(type = "m.tag", kind = RoomAccountData)]
@@ -78,15 +79,16 @@ impl Error for InvalidUserTagName {}
 #[derive(Clone, Debug, PartialEq, Eq, PartialOrd, Ord)]
 #[cfg_attr(not(feature = "unstable-exhaustive-types"), non_exhaustive)]
 pub enum TagName {
-    /// `m.favourite`: The user's favorite rooms. These should be shown with higher precedence
-    /// than other rooms.
+    /// `m.favourite`: The user's favorite rooms.
+    ///
+    /// These should be shown with higher precedence than other rooms.
     Favorite,
 
     /// `m.lowpriority`: These should be shown with lower precedence than others.
     LowPriority,
 
     /// `m.server_notice`: Used to identify
-    /// [Server Notice Rooms](https://matrix.org/docs/spec/client_server/r0.6.1#module-server-notices).
+    /// [Server Notice Rooms](https://spec.matrix.org/v1.2/client-server-api/#server-notices).
     ServerNotice,
 
     /// `u.*`: User-defined tag
@@ -94,7 +96,7 @@ pub enum TagName {
 
     /// A custom tag
     #[doc(hidden)]
-    _Custom(String),
+    _Custom(PrivOwnedStr),
 }
 
 impl TagName {
@@ -105,7 +107,7 @@ impl TagName {
     pub fn display_name(&self) -> &str {
         match self {
             Self::_Custom(s) => {
-                let start = s.rfind('.').map(|p| p + 1).unwrap_or(0);
+                let start = s.0.rfind('.').map(|p| p + 1).unwrap_or(0);
                 &self.as_ref()[start..]
             }
             _ => &self.as_ref()[2..],
@@ -120,7 +122,7 @@ impl AsRef<str> for TagName {
             Self::LowPriority => "m.lowpriority",
             Self::ServerNotice => "m.server_notice",
             Self::User(tag) => tag.as_ref(),
-            Self::_Custom(s) => s,
+            Self::_Custom(s) => &s.0,
         }
     }
 }
@@ -135,14 +137,14 @@ where
             "m.lowpriority" => Self::LowPriority,
             "m.server_notice" => Self::ServerNotice,
             s if s.starts_with("u.") => Self::User(UserTagName { name: s.into() }),
-            s => Self::_Custom(s.into()),
+            s => Self::_Custom(PrivOwnedStr(s.into())),
         }
     }
 }
 
 impl fmt::Display for TagName {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        f.write_str(self.as_ref())
+        self.as_ref().fmt(f)
     }
 }
 
