@@ -3,8 +3,8 @@ use matches::assert_matches;
 use ruma_common::MilliSecondsSinceUnixEpoch;
 use ruma_events::{
     room::{
-        aliases::AliasesEventContent,
-        avatar::{AvatarEventContent, ImageInfo},
+        aliases::RoomAliasesEventContent,
+        avatar::{ImageInfo, RoomAvatarEventContent},
         ThumbnailInfo,
     },
     AnyRoomEvent, AnyStateEvent, AnyStateEventContent, AnySyncStateEvent, RawExt, StateEvent,
@@ -36,16 +36,16 @@ fn aliases_event_with_prev_content() -> JsonValue {
 #[test]
 fn serialize_aliases_with_prev_content() {
     let aliases_event = StateEvent {
-        content: AnyStateEventContent::RoomAliases(AliasesEventContent::new(vec![room_alias_id!(
-            "#somewhere:localhost"
-        )])),
-        event_id: event_id!("$h29iv0s8:example.com"),
+        content: RoomAliasesEventContent::new(vec![
+            room_alias_id!("#somewhere:localhost").to_owned()
+        ]),
+        event_id: event_id!("$h29iv0s8:example.com").to_owned(),
         origin_server_ts: MilliSecondsSinceUnixEpoch(uint!(1)),
-        prev_content: Some(AnyStateEventContent::RoomAliases(AliasesEventContent::new(vec![
-            room_alias_id!("#inner:localhost"),
-        ]))),
-        room_id: room_id!("!roomid:room.com"),
-        sender: user_id!("@carl:example.com"),
+        prev_content: Some(RoomAliasesEventContent::new(vec![
+            room_alias_id!("#inner:localhost").to_owned()
+        ])),
+        room_id: room_id!("!roomid:room.com").to_owned(),
+        sender: user_id!("@carl:example.com").to_owned(),
         state_key: "".into(),
         unsigned: Unsigned::default(),
     };
@@ -59,14 +59,14 @@ fn serialize_aliases_with_prev_content() {
 #[test]
 fn serialize_aliases_without_prev_content() {
     let aliases_event = StateEvent {
-        content: AnyStateEventContent::RoomAliases(AliasesEventContent::new(vec![room_alias_id!(
-            "#somewhere:localhost"
-        )])),
-        event_id: event_id!("$h29iv0s8:example.com"),
+        content: RoomAliasesEventContent::new(vec![
+            room_alias_id!("#somewhere:localhost").to_owned()
+        ]),
+        event_id: event_id!("$h29iv0s8:example.com").to_owned(),
         origin_server_ts: MilliSecondsSinceUnixEpoch(uint!(1)),
         prev_content: None,
-        room_id: room_id!("!roomid:room.com"),
-        sender: user_id!("@carl:example.com"),
+        room_id: room_id!("!roomid:room.com").to_owned(),
+        sender: user_id!("@carl:example.com").to_owned(),
         state_key: "".into(),
         unsigned: Unsigned::default(),
     };
@@ -108,20 +108,17 @@ fn deserialize_aliases_with_prev_content() {
     let json_data = aliases_event_with_prev_content();
 
     assert_matches!(
-        from_json_value::<Raw<StateEvent<AnyStateEventContent>>>(json_data)
-            .unwrap()
-            .deserialize()
-            .unwrap(),
-        StateEvent {
-            content: AnyStateEventContent::RoomAliases(content),
+        from_json_value::<AnyStateEvent>(json_data).unwrap(),
+        AnyStateEvent::RoomAliases(StateEvent {
+            content,
             event_id,
             origin_server_ts,
-            prev_content: Some(AnyStateEventContent::RoomAliases(prev_content)),
+            prev_content: Some(prev_content),
             room_id,
             sender,
             state_key,
             unsigned,
-        } if content.aliases == vec![room_alias_id!("#somewhere:localhost")]
+        }) if content.aliases == vec![room_alias_id!("#somewhere:localhost")]
             && event_id == event_id!("$h29iv0s8:example.com")
             && origin_server_ts == MilliSecondsSinceUnixEpoch(uint!(1))
             && prev_content.aliases == vec![room_alias_id!("#inner:localhost")]
@@ -138,17 +135,17 @@ fn deserialize_aliases_sync_with_room_id() {
     let json_data = aliases_event_with_prev_content();
 
     assert_matches!(
-        from_json_value::<SyncStateEvent<AnyStateEventContent>>(json_data)
+        from_json_value::<AnySyncStateEvent>(json_data)
             .unwrap(),
-        SyncStateEvent {
-            content: AnyStateEventContent::RoomAliases(content),
+        AnySyncStateEvent::RoomAliases(SyncStateEvent {
+            content,
             event_id,
             origin_server_ts,
-            prev_content: Some(AnyStateEventContent::RoomAliases(prev_content)),
+            prev_content: Some(prev_content),
             sender,
             state_key,
             unsigned,
-        } if content.aliases == vec![room_alias_id!("#somewhere:localhost")]
+        }) if content.aliases == vec![room_alias_id!("#somewhere:localhost")]
             && event_id == event_id!("$h29iv0s8:example.com")
             && origin_server_ts == MilliSecondsSinceUnixEpoch(uint!(1))
             && prev_content.aliases == vec![room_alias_id!("#inner:localhost")]
@@ -159,6 +156,7 @@ fn deserialize_aliases_sync_with_room_id() {
 }
 
 #[test]
+#[allow(clippy::cmp_owned)] // seems buggy
 fn deserialize_avatar_without_prev_content() {
     let json_data = json!({
         "content": {
@@ -185,22 +183,19 @@ fn deserialize_avatar_without_prev_content() {
         "type": "m.room.avatar"
     });
 
-    let expected_url = "mxc://matrix.org/rnsldl8srs98IRrs".into();
+    let expected_url = mxc_uri!("mxc://matrix.org/rnsldl8srs98IRrs").to_owned();
 
     #[cfg(feature = "unstable-pre-spec")]
     let expected_url = Some(expected_url);
 
     assert_matches!(
-        from_json_value::<Raw<StateEvent<AnyStateEventContent>>>(json_data)
-            .unwrap()
-            .deserialize()
-            .unwrap(),
-        StateEvent {
-            content: AnyStateEventContent::RoomAvatar(AvatarEventContent {
+        from_json_value::<AnyStateEvent>(json_data).unwrap(),
+        AnyStateEvent::RoomAvatar(StateEvent {
+            content: RoomAvatarEventContent {
                 info: Some(info),
                 url,
                 ..
-            }),
+            },
             event_id,
             origin_server_ts,
             prev_content: None,
@@ -208,7 +203,7 @@ fn deserialize_avatar_without_prev_content() {
             sender,
             state_key,
             unsigned
-        } if event_id == event_id!("$h29iv0s8:example.com")
+        }) if event_id == event_id!("$h29iv0s8:example.com")
             && origin_server_ts == MilliSecondsSinceUnixEpoch(uint!(1))
             && room_id == room_id!("!roomid:room.com")
             && sender == user_id!("@carl:example.com")
@@ -239,7 +234,7 @@ fn deserialize_avatar_without_prev_content() {
                             && *thumb_height == UInt::new(334)
                             && *thumb_mimetype == Some("image/png".into())
                             && *thumb_size == UInt::new(82595)
-                            && *thumbnail_url == mxc_uri!("mxc://matrix.org/98irRSS23srs")
+                            && thumbnail_url == mxc_uri!("mxc://matrix.org/98irRSS23srs")
                     )
             )
             && url == expected_url
@@ -290,17 +285,10 @@ fn deserialize_member_event_with_top_level_membership_field() {
 fn deserialize_full_event_convert_to_sync() {
     let json_data = aliases_event_with_prev_content();
 
-    let full_ev = from_json_value::<Raw<AnyStateEvent>>(json_data).unwrap().deserialize().unwrap();
-
-    // Test conversion to sync event (without room_id field)
-    let sync: AnySyncStateEvent = full_ev.into();
-    let sync_json = to_json_value(sync).unwrap();
+    let full_ev: AnyStateEvent = from_json_value(json_data).unwrap();
 
     assert_matches!(
-        from_json_value::<Raw<AnySyncStateEvent>>(sync_json)
-            .unwrap()
-            .deserialize()
-            .unwrap(),
+        AnySyncStateEvent::from(full_ev),
         AnySyncStateEvent::RoomAliases(SyncStateEvent {
             content,
             event_id,
